@@ -72,5 +72,7 @@ if ENABLE_API:
                 else:
                     search_in = ""
 
-                context.update({"answers": get_answers(question, search_in)})
+                draft = context["request"].GET["draft"]
+
+                context.update({"answers": get_answers(question, search_in, draft)})
             return context
