@@ -14,7 +14,9 @@ def AnswerView(request):
         else:
             search_in = ""
 
-        answers = get_answers(question, search_in)
+        draft = request.GET["draft"]
+
+        answers = get_answers(question, search_in, draft)
 
         jsondata = []
 
